@@ -10,7 +10,7 @@
 #define KASTEN_FILESYSTEMBROWSERTOOLFACTORY_HPP
 
 // lib
-#include <kasten/kastencontrollers_export.hpp>
+#include "kastencontrollers_export.hpp"
 // Kasten core
 #include <Kasten/AbstractToolFactory>
 
@@ -22,8 +22,12 @@ class KASTENCONTROLLERS_EXPORT FileSystemBrowserToolFactory : public AbstractToo
 {
 public:
     explicit FileSystemBrowserToolFactory(DocumentSyncManager* documentSyncManager);
+    FileSystemBrowserToolFactory(const FileSystemBrowserToolFactory&) = delete;
+
     ~FileSystemBrowserToolFactory() override;
 
+    FileSystemBrowserToolFactory& operator=(const FileSystemBrowserToolFactory&) = delete;
+
 public: // AbstractToolFactory API
     AbstractTool* create() const override;
 
